@@ -12,7 +12,7 @@ from cast_common.logger import Logger
 from pandas import DataFrame
 from time import perf_counter, ctime
 from base64 import b64decode
-from json import dumps
+
 
 __author__ = "Nevin Kaplan"
 __copyright__ = "Copyright 2022, CAST Software"
@@ -26,7 +26,7 @@ class RestCall(Logger):
     _time_tracker_df  = DataFrame()
     _track_time = True
 
-    def __init__(self, base_url, user=None, password=None, basic_auth=None, track_time=False,log_level=INFO):
+    def __init__(*,self, base_url, user=None, password=None, basic_auth=None, track_time=False,log_level=INFO):
         super().__init__(level=log_level)
         if base_url[-1]=='/': 
             base_url=base_url[:-1]
@@ -56,7 +56,8 @@ class RestCall(Logger):
         #self._session.headers.update({'Authorization': self._auth})
 
 
-    def get(self, url = "",header={'Accept': 'application/json'}):
+#    def get(self, url = "", headers = {'Accept': 'application/json'}):
+    def get(self, url = "",header=None):
         start_dttm = ctime()
         start_tm = perf_counter()
 
@@ -69,6 +70,10 @@ class RestCall(Logger):
             # else:
             #     resp = get(url= u, auth = self._auth, headers={'Accept': 'application/json'})
 
+            if header is None:
+                header={'Accept': 'application/json'}
+
+#            resp = self._session.get(u, timeout = (5, 15),auth=self._auth,headers={'Accept': 'application/json'})
             resp = self._session.get(u, timeout = (5, 15),auth=self._auth,headers=header)
             resp.raise_for_status()
 
@@ -102,14 +107,14 @@ class RestCall(Logger):
 
         return 0, "{}"
     
-    def post(self, url = "",data = {},header={'Accept': 'application/json'}):
+    def post(self, url = "",data = {}):
 
         try:
             if len(url) > 0 and url[0] != '/':
                 url=f'/{url}'
             u = urllib.parse.quote(f'{self._base_url}{url}',safe='/:&?=')
 
-            resp = self._session.post(u,data=dumps(data),timeout = (5, 15),auth=self._auth,headers=header)
+            resp = self._session.post(u,data=data,timeout = (5, 15),auth=self._auth,headers={'Accept': 'application/json'})
             resp.raise_for_status()
 
             if resp.status_code == codes.ok:
